unit GLOBALS; {Unit 1 of SEASQUAD.PAS}

interface

  const
    left = 0;
    right = 1;
    dim = 100;
    assumedZero = 0.00001;
    maxOrder = 12;
    maxArray = 500;


  const {ASCII Codes}
    TAB = 9;
    CR = 13;
    SPACE = 32;
    Annual = 1;
    Quarterly = 4;
    Monthly = 12;
    Other = 9;

  type
    complex = record
        re, im: real;
      end;

  type
    polar = record
        argu, modu: real;
      end;

  type
    points = record
        x, y: real
      end;

  type
    vector = array[-2..100] of real;

  type
    ivector = array[-10..50] of integer;

  type
    longVector = array[0..maxArray] of real;

  type
    matrix = array[0..25] of array[0..25] of real;

  type
    seasQuadratic = array[0..2] of extended;

  type
    seasVector = array[0..36] of extended;

  type
    seasMatrix = array[0..12] of array[0..12] of extended;

  type
    pointsVector = array[0..maxArray] of points;

  type
    complexVector = array[-20..20] of complex;

  type
    polarVector = array[-20..20] of polar;

  type
    IBOX = record
        X0: integer;  {the horizontal value of the graphics origin}
        Y0: integer;  {the vertical value of the graphics origin}
        X1: integer; {left of the graphics bounding box}
        Y1: integer; {top or bottom of the graphics bounding box}
        X2: integer; {right of the graphics bounding box}
        Y2: integer; {bottom or top of graphics the bounding box}
        XC: integer; {horizontal value of the centre of window}
        YC: integer;  {vertical value of the centre of window}
        BOXWDT: integer; {Width of the Bounding Box}
        BOXHGT: integer; {Height of the Bounding Box}
        xAxis: boolean;
        yAxis: boolean;
        xScale: boolean;
        yScale: boolean;
        doFrame: boolean;
        doMarks: boolean;
      end;

  type
    rBOX = record
        xMax: real;  {the maximum value of x in the dataVector}
        xMin: real;  {the minimum value of x in the dataVector}
        yMax: real;  {the maximum value of y in the dataVector}
        yMin: real;  {the minimum value of y in the dataVector}
        xMean: real; {the mean value of x in the dataVector}
        yMean: real; {the variance value of y in the dataVector}
        xVar: real; {the variance value of x in the dataVector}
        yVar: real; {the mean value of y in the dataVector}
        yUB: real;   {yUB >= yMax: an upper bound for y}
        yLB: real;   {yLB <= yMin: a lower bound for y}
        xLB: real;   {xLB <= xMin: a left (lower) bound for x}
        xRB: real;    {xRB >= xMax: a right (upper) bound for x}
        yRange: real; {yUB - yLB}
        xRange: real; {xMax - xMin;}
        NOPUNCT: integer; {number of data points}
        dataChar: char; {q: quaterly, m: monthly. a: annual}
        dataFrequency: integer; {Annual, Quarterly, Monthly, Other}
        slopeDegrees: real; {DELETE?}
      end;

  type
    polyParameters = record
        alpha: vector; {parameters ofthe polynomial relative to the orthogonal basis}
        gamma: vector; {auxilliary parameters of the three-term recurrence}
        delta: vector; {auxilliary parameters of the three-term recurrence}
        polyDegree: integer;
        tStart: integer; {the intial index of the polynomial time trend}
      end;

  type
    filterRecord = record
        filterOrder: integer;   {Order of Wiener-Komogorov Filter}
        rho: real; {modulus of the poles}
        lambda: real; {smoothing parameter}
        s: integer; {seasonal frequency}
        sPlus: integer; {order ofthe augmented filter}
        gainChar: char; {F for requency response, A amplitude spectrum}
        seasonality: integer; {Monthly Quarterly, for the seasonal adjustment filter}
        filterFactor: real; {factor for adjustiing filter gain}
      end;


  {GLOBAL Flags: Should GLOBAL flags end in G e.g. AllsDoneG?}
  var
    noSCREENBOX, PSPict, TeXFormat, graphicsOn, stability: boolean;
    allsDone, noPageParameters, noModel, suppressReplace: boolean;
    thereisData, logsTaken, trendEstimated, weHaveTrendResiduals: boolean;
    residualsInData, weHaveATrend, noFilter, noFilterSpec: boolean;

{Graphics Parameters}
  var
    SCREENBOX, POSTBOX: IBOX;
    figNumber: integer;
    currentMode: integer;

{Data Parameters}
  var
    dataBOX, trendBox, residueBOX, cycleBOX: rBOX;
    dataVector, trendVector, residueVec, seasonVec, PolyWgts: longVector; {adjustedVec,}
    polyParas: polyParameters;

  {Filter Parameters: should all of these become part of FilterRecord?:}
  var
    filterSpec: FilterRecord;
    poles, zeros: complexVector; {Poles and zeros of the filter}
    gamma, delta: complexVector; {Coefficient vectors of the filter}
    sigmaVec, rhoVec: seasVector; {the Cramer-Wold factors of the numerator and denominator}
    sigma1Vec1, rho1Vec, sigma2Vec1, rho2Vec: seasVector; {the Cramer-Wold factors of the numerator and denominator}


{Seasonal Filter Parameters}
  var
{theta0, phi0,}
    theta, phi: seasVector; {these are numerator, denominator of Seasonal Filter}
    theta1, phi1, theta2, phi2: seasVector;
    cartPoles, cartZeros: complexVector;
    polarPoles, polarZeros: polarVector;
    offset, ordinary, twoPass, threePass: boolean;


implementation

end. {GLOBALS: Unit 1 of SEASIDE.PAS}

