unit ORGANISE; {unit 7 of SEASQUAD.PAS}

interface

  uses
    GLOBALS, MATHS, UTILS, SCREEN, POST, ENGINES, Dos, Crt, Graph;

  procedure CentralFilterVec (var phi, theta: seasVector;
                  var sigmaVec, rhoVec: seasVector;
                  var lambda, rho: real);

  procedure OrdinaryFilter (var phi, theta: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);

  procedure TwoPassFilter (var phi1, theta1, phi2, theta2: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);

  procedure GetTheOffsets (var zetaSub, zetaSup: vector;
                  var quadNo: integer);

  procedure OffsetFilterVecs (var phi1, theta1, phi2, theta2: seasVector;
                  var lambda, rho: real;
                  var quadNo: integer);

  procedure TripleFilter (var phi, theta, phi1, theta1, phi2, theta2: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);

implementation

{_________________________________________________}

  procedure CentralFilterVec (var phi, theta: seasVector;
                  var sigmaVec, rhoVec: seasVector;
                  var lambda, rho: real);
    var
      s: integer;

  begin

    s := 12;
    MakeSigmaVec(sigmaVec, s);
    MakeRhoVec(rhoVec, rho, s);
    Laurent(sigmaVec, theta, s-1);
    Laurent(rhoVec, phi, s-1);

    WKCoefficients(phi, theta, s, lambda);

  end; {CentralFilterVec}

{_________________________________________________}

  procedure OrdinaryFilter (var phi, theta: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);

    var
      sigmaVec, rhoVec: seasVector;
      lambda, rho: real;
      s, sPlus, quadNo: integer;
      F: text;
      legend: string;

  begin
    ordinary := true;
    offset := false;
    twoPass := false;
    threePass := false;

    {s := 12;}
    quadNo := 6;
    sPlus := 2 * quadNo; {twice quadNo }

    if noPageParameters then
      PageSetUp(SCREENBOX, POSTBOX, PSPict, TeXFormat); {in UTILS}

    ClrScr;
    Writeln;
    Writeln;
    Writeln('   THE ORDINARY SEASONAL-ADJUSTMENT FILTER FILTER');
    Writeln;
    Writeln('   The ordinary seasonal adjustment filter comprises poles and zeros located');
    Writeln('   at precisely the seasonal frequencies, which are the fundamental seasonal');
    Writeln('   frequency and its harmonices  within the interval [0, pi]. The  zeros lie');
    Writeln('   on the  circumference on the unit  circle and the poles, which lie on the');
    Writeln('   same radii, are at a  small distance from the circle. The zersos serve to');
    Writeln('   nullify the elelements of the data at the seasonal frequencies,  and  the');
    Writeln('   poles are  to ensure that these effects are limited to  the vicinities of');
    Writeln('   the seasonal frequencies.');
    Writeln(' ' : 65, '<RETURN>');
    Readln;

    Writeln('    Specify value of the lambda');
    ReadBoundedNumber(0.0, 1.0, lambda);
    Writeln('    Specify the value of the modulus rho');
    ReadBoundedNumber(0.0, 1.0, rho);
    CentralFilterVec(phi, theta, sigmaVec, rhoVec, lambda, rho);

    WKCoefficients(phi, theta, sPlus, lambda);

    GetFilterGainVector(SCREENBOX, dataBOX, dataVector, phi, theta, phi1, theta1, phi2, theta2, sPlus);

    GetGraphics(graphicsOn, SCREENBOX, currentMode);

    ScreenFrameLite(dataBOX, SCREENBOX);
    DoDecAxis(SCREENBOX);

    ScreenPlotMod(dataBOX, SCREENBOX, dataVector);

    CallForReturn;
    Readln;
    CloseGraph;
    RestoreCrtMode;
    ClrScr;

    legend := '';

    if PSPict then
      PostSpectraPlot(F, dataBOX, dataVector, POSTBOX, legend);

  end; {OrdinaryFilter}

{_________________________________________________}

  procedure TwoPassFilter (var phi1, theta1, phi2, theta2: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);

    var
      sigmaVec, rhoVec: seasVector;
      lambda, rho, zeta: real;
      i, s, sPlus, quadNo: integer;
      F: text;
      legend: string;

  begin
    ordinary := false;
    offset := true;
    twoPass := true;
    threePass := false;

    if noPageParameters then
      PageSetUp(SCREENBOX, POSTBOX, PSPict, TeXFormat); {in UTILS}

    ClrScr;
    Writeln;
    Writeln;
    Writeln('   THE TWOPASS OFFSET FILTER');
    Writeln;
    Writeln('   The  twopass offset seasonal  adjustment filter comprises two filters  that');
    Writeln('   are applied in  sequence. The filters have poles and zeros that are located');
    Writeln('   at small distances below and above the  seasonal frequencies. The intention');
    Writeln('   is to widen the stopands that surround the seasonal frequencies. An adverse');
    Writeln('   effect of this design is to  allow a minor leakage to occur at the seasonal');
    Writeln('   frequencies, which will become more severe as the offsets are increased.');
    Writeln;
    Writeln(' ' : 70, '<RETURN>');
    Readln;


    Writeln('    Specify value of the lambda');
    ReadBoundedNumber(0.0, 1.0, lambda);
    Writeln('    Specify value of the  rho');
    ReadBoundedNumber(0.0, 1.0, rho);
    Writeln('    Specify value of the  offset zeta  in degrees');
    ReadBoundedNumber(0.0, 4.0, zeta);

    s := 12;
    quadNo := 5;
    sPlus := 2 * quadNo; {twice quadNo }
    zeta := -2.0;
    CompoundQuads(sigmaVec, rhoVec, rho, zeta, sPlus, quadNo);


    Laurent(sigmaVec, theta1, sPlus);
    Laurent(rhoVec, phi1, sPlus);
    WKCoefficients(phi1, theta1, sPlus, lambda);

    zeta := 2.0;
    quadNo := 6;
    sPlus := 2 * quadNo;  {twice quadNo }
    CompoundQuads(sigmaVec, rhoVec, rho, zeta, sPlus, quadNo);
    Laurent(sigmaVec, theta2, sPlus);
    Laurent(rhoVec, phi2, sPlus);
    WKCoefficients(phi2, theta2, sPlus, lambda);

{ordinary := true;}
{twoPass := false;}


    GetFilterGainVector(SCREENBOX, dataBOX, dataVector, phi, theta, phi1, theta1, phi2, theta2, sPlus);

    GetGraphics(graphicsOn, SCREENBOX, currentMode);

    ScreenFrameLite(dataBOX, SCREENBOX);
    DoDecAxis(SCREENBOX);

    ScreenPlotMod(dataBOX, SCREENBOX, dataVector);

    CallForReturn;
    Readln;
    CloseGraph;
    RestoreCrtMode;
    ClrScr;

    legend := '';

    if PSPict then
      PostSpectraPlot(F, dataBOX, dataVector, POSTBOX, legend);

  end; {TwoPassFilter}

{_________________________________________________}

  procedure GetTheOffsets (var zetaSub, zetaSup: vector;
                  var quadNo: integer);
    var
      i, s, limit: integer;
      seasFreak: integer;
      STR1, addString: string;
      degreesBelow, degreesAbove: integer;

  begin

    seasFreak := 30;

    degreesBelow := 0;
    degreesAbove := 0;
    s := 2 * quadNo;
    limit := 180 div s;

    for i := 1 to quadNo do
      begin {i}
        Writeln('    Specify the  additional poles and zeros adjacent to the seasonal ');
        addString := IntegerToString(seasFreak);
        STR1 := Concat('    frequency at ', addString, ' degrees');
        Writeln(STR1);

        Writeln;
        Writeln('    Specify the number of degrees below the seasonal frequency');
        GetBoundedInteger(0, limit, degreesBelow);
        if degreesBelow > 0 then
          zetaSub[i] := -degreesBelow
        else
          zetaSub[i] := 0.0;

        Writeln('    Specify the number of degrees above the seasonal frequency');
        GetBoundedInteger(0, limit, degreesAbove);
        if degreesAbove > 0 then
          zetaSup[i] := degreesAbove
        else
          zetaSup[i] := 0.0;

        seasFreak := seasFreak + 30;
      end; {i}

{compound the zetaSub and zetaSup into phi1, phi2 and theta1, theta2}

  end; {GetTheOffsets}

{_________________________________________________}

  procedure OffsetFilterVecs (var phi1, theta1, phi2, theta2: seasVector;
                  var lambda, rho: real;
                  var quadNo: integer);

    var
      zetaSub, zetaSup: vector;
      sigmaVec, rhoVec: seasVector;
      i, sPlus: integer;

  begin
    quadNo := 6;
    sPlus := 2 * quadNo;

    GetTheOffsets(zetaSub, zetaSup, quadNo);

    for i := 1 to quadNo do
      Writeln(' sub-offset frequency[', i : 2, '] = ', zetaSub[i] : 6 : 4);
    Writeln('' : 60, '<RETURN>');
    Readln;

    for i := 1 to quadNo do
      Writeln(' supra-offset frequency[', i : 2, '] = ', zetaSup[i] : 6 : 4);
    Writeln('' : 60, '<RETURN>');
    Readln;

    quadNo := 5;
    sPlus := 2 * quadNo; {twice quadNo }
    NewCompoundQuads(sigmaVec, rhoVec, zetaSub, rho, quadNo);
{This comprises the vector of offsets zetaSub}

    Laurent(sigmaVec, theta1, sPlus);
    Laurent(rhoVec, phi1, sPlus);
    WKCoefficients(phi1, theta1, sPlus, lambda);

    quadNo := 6;
    sPlus := 2 * quadNo;

    NewCompoundQuads(sigmaVec, rhoVec, zetaSup, rho, quadNo);
    Laurent(sigmaVec, theta2, sPlus);
    Laurent(rhoVec, phi2, sPlus);
    WKCoefficients(phi2, theta2, sPlus, lambda);


  end; {OffsetFilterVecs }

{_________________________________________________}

  procedure TripleFilter (var phi, theta, phi1, theta1, phi2, theta2: seasVector;
                  var dataVector: longvector;
                  var dataBOX: rBOX;
                  var SCREENBOX: IBOX);
    var
      lambda, rho: real;
      quadNo, sPlus: integer;
      F: text;
      legend: string;

  begin

    if noPageParameters then
      PageSetUp(SCREENBOX, POSTBOX, PSPict, TeXFormat); {in UTILS}

    ClrScr;
    Writeln;
    Writeln;
    Writeln('    THE TRIPLE OFFSET FILTER');
    Writeln;
    Writeln('    The triple filter supplements the ordinary monthly seasonal adjustment');
    Writeln('    filter by two offset filters that have their pole-zero pairs below and');
    Writeln('    above the sesonal frequencies.The user is asked to specify the offsets');
    Writeln('    in numbers of degrees');
    Writeln;
    Writeln(' ' : 66, '<RETURN>');
    Readln;
    
    Writeln('    Specify value of the lambda');
    ReadBoundedNumber(0.0, 1.0, lambda);
    Writeln('    Specify value of the  rho');
    ReadBoundedNumber(0.0, 1.0, rho);

    quadNo := 5;
    sPlus := 2 * quadNo; {twice quadNo }

    offset := true;
    CentralFilterVec(phi, theta, sigmaVec, rhoVec, lambda, rho);

    offset := true;
    OffsetFilterVecs(phi1, theta1, phi2, theta2, lambda, rho, quadNo); {in ORGANISE}

    ThreePass := true;

    GetFilterGainVector(SCREENBOX, dataBOX, dataVector, phi, theta, phi1, theta1, phi2, theta2, sPlus);

    GetGraphics(graphicsOn, SCREENBOX, currentMode);

    ScreenFrameLite(dataBOX, SCREENBOX);
    DoDecAxis(SCREENBOX);

    ScreenPlotMod(dataBOX, SCREENBOX, dataVector);

    CallForReturn;
    Readln;
    CloseGraph;
    RestoreCrtMode;
    ClrScr;

    legend := '';

    if PSPict then
      PostSpectraPlot(F, dataBOX, dataVector, POSTBOX, legend);

  end; {TripleFilter}
{_________________________________________________}

end. {ORGANISE: Unit 7 of SEASUAD.PAS}

