unit POST; {unit 5 of SEASQUAD.PAS}

interface

  uses
    GLOBALS, UTILS, MATHS;

  procedure PostHeader (var F: text;
                  var POSTBOX: IBOX;
                  TeXFormat: boolean);

  procedure PostFooter (var F: text;
                  var POSTBOX: IBOX;
                  legend: string;
                  TexFormat: boolean);

  procedure PostMarks (var F: text;
                  XSTART, YSTART: real;
                  taly, firstMark, farBound, STEP: real;
                  Axis: string);

  procedure PostFrame (var F: text;
                  var dataBOX: rBOX;
                  var POSTBOX: IBOX);

  procedure PostVertAxis (var F: text;
                  XSTART, YSTART: integer;
                  taly, firstMark, farBound, VSTEP: real);

  procedure PostZeroPiAxis (var F: text;
                  var POSTBOX: IBOX);

  procedure PostDoDecAxis (var F: text;
                  var POSTBOX: IBOX);

  procedure PostFrameLite (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX);

  procedure PostPlot (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);

  procedure PostPlot2 (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);

  procedure PostPlotMod (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);


  procedure PostSpectraPlot (var F: text;
                  var plotBOX: rBOX;
                  var plotVector: longVector;
                  var POSTBOX: IBOX;
                  var legend: string);

implementation

 {________________________________________________}

  procedure PostHeader (var F: text;
                  var POSTBOX: IBOX;
                  TeXFormat: boolean);
    var
      BOXHGT, BOXWDT, INDENT: integer;
      LLx, LLy, URx, URy: integer;
      xOrigin, yOrigin: integer;

  begin
      {xOrigin := 160;}
      {yOrigin := 560;}

    BOXWDT := POSTBOX.X2 - POSTBOX.X1;
    BOXHGT := POSTBOX.Y2 - POSTBOX.Y1;

    xOrigin := (595 - BOXWDT) div 2;
    yOrigin := 730 - BOXHGT;

    if TeXFormat then
      Writeln(F, '\special{postscript')
    else
      begin
        LLx := xOrigin - 45;
        LLy := yOrigin - 25;
        URx := xOrigin + BOXWDT + 45;
        URy := yOrigin + BOXHGT + 10;
        Writeln(F, '%!PS-Adobe-2.0');
        Writeln(F, '%%Creator: SigmaPi');
        Writeln(F, '%%BoundingBox:', LLx : 3, '  ', LLy : 3, '  ', URx : 3, '  ', URy : 3);
      end;

    Writeln(F, '/showxhatch');
    Writeln(F, '{/label exch def');
    Writeln(F, '/y exch def');
    Writeln(F, '/x exch def');
    Writeln(F, 'x  y  moveto');
    Writeln(F, '0  5 rlineto');
    Writeln(F, 'stroke');
    Writeln(F, 'x  y  moveto');
    Writeln(F, '0 -20 rmoveto');
    Writeln(F, 'label dup stringwidth pop 2 div neg 0 rmoveto show} def');

    Writeln(F, '/showyhatch');
    Writeln(F, '{/label exch def');
    Writeln(F, '/y exch def');
    Writeln(F, '/x exch def');
    Writeln(F, 'x  y  moveto');
    Writeln(F, ' 5 0 rlineto');
    Writeln(F, 'stroke');
    Writeln(F, 'x  y  moveto');
    Writeln(F, '-15 -2 rmoveto');
    Writeln(F, 'label dup stringwidth pop neg 0 rmoveto show} def');


    if TeXFormat then
      begin {TeXFormat}
        INDENT := Round(((12 * 72) / 2.54 - BOXWDT) / 2);
        Writeln(F, INDENT : 2, '  ', -(BOXHGT + 15) : 2, '  translate');
      end {TeXFormat}
    else
      Writeln(F, xOrigin : 3, '  ', yOrigin : 3, ' translate ');

    Writeln(F, 'newpath');
    Writeln(F, '0.5 setlinewidth');

  end; {PostHeader}

 {_________________________________________________}

  procedure PostFooter (var F: text;
                  var POSTBOX: IBOX;
                  legend: string;
                  TexFormat: boolean);

    var
      BOXHGT: integer;
      figNumberString: string;

  begin
   {Writeln(F, 'stroke');}
    figNumberString := IntegerToString(figNumber);
    if TexFormat then
      begin
        Writeln(F, 'showpage}');
        BOXHGT := POSTBOX.Y2 - POSTBOX.Y1;
        Writeln(F, '\vbox to ', BOXHGT + 35 : 3, ' pt');
        Writeln(F, ' {\hrule width 12cm height 0cm depth 0cm \vfill}');
        Writeln(F, '\medskip');
        Writeln(F, '{\par\noindent{\bf Figure ', figNumber : 1, '.} ');
        Write(F, legend);
        Writeln(F, '\par}');
        Writeln(F, '\medskip');
      end
    else
      begin
        Writeln(F, 'showpage');
        Writeln(F, '%%Trailer');
        Writeln(F, '%%EOF');
        Writeln(F, '%% Figure ', fignumber : 1, '. ', legend);
      end;

    figNumber := figNumber + 1;

  end; {PostFooter}

 {_________________________________________________}

  procedure PostMarks (var F: text;
                  XSTART, YSTART: real;
                  taly, firstMark, farBound, STEP: real;
                  Axis: string);

    var
      toly, HR, VT: real;
      tolyString: string;

  begin {PostMarks}

    toly := firstMark;
    HR := XSTART;
    VT := YSTART;

    while Abs(toly) <= Abs(farBound) do

      begin {while toly}
        tolyString := TalyToString(toly);
        if Axis = 'xScale' then
          begin
            Writeln(F, HR : 5 : 2, '  ', VT : 5 : 2, '  (', tolyString, ') showxhatch');
            HR := HR + STEP;
          end;

        if Axis = 'yScale' then
          begin
            Writeln(F, HR : 5 : 2, '  ', VT : 5 : 2, '  (', tolyString, ') showyhatch');
            VT := VT + STEP;
          end;

        toly := toly + taly;
      end; {while TOLY}

  end; {PostMarks: Marks and Numbers}

 {_________________________________________________}

  procedure PostFrame (var F: text;
                  var dataBOX: rBOX;
                  var POSTBOX: IBOX);

 {This is the revised version of PostFrame}

    var
      sign, Ycap: integer;
      firstHATCH, vSTEP, hSTEP: real;
      rxPos, rxNeg, ryPos, ryNeg, taly, increment: real;
      nearBound, farBound, boundRange, startMark: real;
       {Q: text;}

  begin{PostFrame}
     {ShowMessage(' We ARE IN POSTFRAME');}
    with POSTBOX, dataBOX do
      begin
        yUB := yMax;
        yLB := yMin;

        yRange := yMax - yMin; {This will become YUB - yLB}
        xRange := xMax - xMin;

 {(X1,  Y1) is the bottom left of the IBOX}
 {(X2,  Y2) is the top lright of the IBOX}

        X0 := X1; {Default for Graphics Origin. integer}
        Y0 := Y1; {Default for Graphics Origin. integer}

 {BOXWDT := X2 - X1;}
  {Width of Bounding Box: real valued entity}
 {BOXHGT := Y2 - Y1; }
  {Height of Bounding Box: : real valued entity}

        if doMarks then
          begin
            Writeln(F, '/Symbol findfont');
            Writeln(F, '10 scalefont  setfont');
          end;
        if doFrame then
          begin
            Writeln(F, X1 : 3, '  ', Y1 : 3, '  moveto');
            Writeln(F, X1 : 3, '  ', Y2 : 3, '  lineto');
            Writeln(F, X2 : 3, '  ', Y2 : 3, '  lineto');
            Writeln(F, X2 : 3, '  ', Y1 : 3, '  lineto');
            Writeln(F, 'closepath');
            Writeln(F, 'stroke');
            Writeln(F, 'newpath');
          end;

        if yScale = true then
          begin {Do the yScale}
  {...............................................................................................}

            if yMin * yMax >= 0 then
              begin {yMin, yMax > or yMin, yMax < 0}

                if yMax < 0 then
                  begin
                    sign := -1;
                    nearBound := yMax;
                    farBound := yMin;
                  end
                else
                  begin
                    sign := 1;
                    nearBound := yMin;
                    farBound := yMax
                  end;

                if ((farBound - nearBound) / farBound) < 0.3 then
                  begin {small boundRange}

                    nearBound := nearBound - sign * (0.2 * yRange);
                    farBound := farBound + sign * (0.2 * yRange);
                    if sign = 1 then
                      begin
                        yUB := farBound;
                        yLB := nearBound
                      end
                    else
                      begin
                        yLB := farBound;
                        yUB := nearBound
                      end;

                    boundRange := Abs(farBound - nearBound);

                    TallyPoints(boundRange, taly);
                    startMark := Trunc(nearBound / taly) * taly;
                    if (Abs((startMark - nearBound) / nearBound) > 0.0001) then
                      startMark := startMark + sign * taly;

                    if sign = 1 then
                      Ycap := Y1
                    else
                      Ycap := Y2;

                    FIRSTHATCH := Ycap + (startMark - nearBound) * BOXHGT / boundRange;
                  end {small boundRange}
                else{large boundRange}
                  begin {yMin = 0.0}

                    if yMax > 0 then
                      begin
                        farBound := 1.2 * yMax;
                        yUB := farBound;
                        yLB := 0.0;
                      end
                    else
                      begin
                        farBound := 1.2 * yMin;
                        yUB := 0.0;
                        yLB := farbound;
                      end;

                    boundRange := Abs(farBound);
                    TallyPoints(boundRange, taly);
                    startMark := 0.0;
                    FIRSTHATCH := Ycap;
                  end; {large boundRange}

                vSTEP := taly * (BOXHGT / boundRange);
                hSTEP := 0.0;
                if doMarks then
                  PostMarks(F, X1, firstHATCH, sign * taly, startMark, farBound, sign * vSTEP, 'yScale')

              end;{yMin, yMax > or yMin, yMax < 0}
 {...............................................................................................}

            if (yMin < 0.0) and (yMax > 0.0) then
              begin {yMin < 0.0}
                ryPos := yMax;
                ryNeg := yMin;

                increment := 0.1 * (yMax - yMin);
                if yMax > Abs(yMin) then
                  begin
                    ryPos := 1.2 * yMax;
                    ryNeg := yMin - increment;
                  end
                else
                  begin
                    ryNeg := 1.2 * yMin;
                    ryPos := yMax + increment
                  end;
                yUB := ryPos;
                yLB := ryNeg;

                Y0 := Y1 - Round(BOXHGT * ryNeg / (ryPos - ryNeg));
 {this draws the horizontal axis through y = 0}

                if (xScale = true) or (xAxis = true) then
                  begin
                    Writeln(F, X1 : 3, '  ', Y0 : 3, '  moveto');
                    Writeln(F, X2 : 3, '  ', Y0 : 3, '  lineto');
                    Writeln(F, 'stroke');
                    Writeln(F, 'newpath');
                  end;

                if ryPos > Abs(ryNeg) then
                  begin
                    TallyPoints(ryPos, taly);
                    vSTEP := (Y2 - Y0) * (taly / ryPos);
                  end
                else {if ryPos < Abs(ryNeg)}
                  begin
                    TallyPoints(-ryNeg, taly);
                    vSTEP := (Y1 - Y0) * taly / ryNeg;
                  end;

                hSTEP := 0.0;
                if doMarks then
                  begin {doMarks}
                    PostMarks(F, X1, Y0, taly, 0.0, ryPos, vSTEP, 'yScale');
                    PostMarks(F, X1, Y0, -taly, 0.0, ryNeg, -vSTEP, 'yScale');
                  end; {doMarks}

              end; {yMin < 0.0 and yMax > 0.0}
   {...............................................................................................}
             {yRange := yUB - LB;}

            Writeln(F, 'stroke');
            Writeln(F, 'newpath')

          end; {Do the yScale}
 {------------------------------------------------------}

        if xScale then
          begin {Do the xScale}

   {...............................................................................................}

            if (xMin <= 0.0) and (xMax >= 0) then
              begin {xMin <= 0.0}
                rxPos := xMax;
                rxNeg := xMin;

                if (xMin < 0.0) then
                  X0 := X1 - Round(BOXWDT * rxNeg / (rxPos - rxNeg))
                else
                  X0 := X1;

                if (xMin < 0.0) and (yScale = true) then
                  begin  {This provides the vertical axis through x =0}
                    Writeln(F, X0 : 3, '  ', Y1 : 3, '  moveto');
                    Writeln(F, X0 : 3, '  ', Y2 : 3, '  lineto');
                    Writeln(F, 'stroke');
                    Writeln(F, 'newpath');
                  end;

                if rxPos > Abs(rxNeg) then
                  begin
                    TallyPoints(rxPos, taly);
                    hSTEP := (X2 - X0) * (taly / rxPos);
                  end
                else
                  begin
                    TallyPoints(-rxNeg, taly);
                    hSTEP := (X1 - X0) * (taly / rxNeg);
                  end;

                vSTEP := 0;
                if doMarks then
                  begin
                    PostMarks(F, X0, Y1, taly, 0, rxPos, hSTEP, 'xScale');
                    PostMarks(F, X0, Y1, -taly, 0, rxNeg, -hSTEP, 'xScale');
                  end;

              end; {xMin <= 0.0 and xMax >= 0}

   {...............................................................................................}

            if xMin * xMax > 0.0 then
              begin {xMin, xMax < 0 or xMin, xMax >0}
                sign := 1;
                if xMax < 0 then
                  sign := -1;

                TallyPoints(xRange, taly);
                if xMin > 0 then
                  begin
                    farBound := xMax;
                    nearBound := xMin;
                  end;
                if xMax < 0 then
                  begin
                    farBound := xMin;
                    nearBound := xMax;
                  end;

                startMark := Trunc(nearBound / taly) * taly;
                if (Abs((startMark - nearBound) / nearBound) > 0.001) then
                  startMark := startMark + sign * taly;
                hSTEP := (BOXWDT) * (taly / xRange);
                vSTEP := 0.0;
                if sign = 1 then
                  firstHATCH := X1 + ((startMark - xMin) * BOXWDT) / xRange
                else
                  firstHATCH := X2 - ((xMax - startMark) * BOXWDT) / xRange;
                PostMarks(F, firstHATCH, Y1, sign * taly, startMark, farBound, sign * hSTEP, 'xScale');
              end;

   {...............................................................................................}

            Writeln(F, 'stroke');
            Writeln(F, 'newpath');


          end; {Do the xScale}

 {------------------------------------------------------}

        xRange := xMax - xMin;
        yRange := yUB - xLB;

      end; {with POSTBOX, dataBOX}

  end; {PostFrame: PostScript Framework}

 {________________________________________________}

  procedure PostVertAxis (var F: text;
                  XSTART, YSTART: integer;
                  taly, firstMark, farBound, VSTEP: real);

    var
      toly, HR, VT: real;
      tolyString: string;

  begin {PostVertAxis}

    toly := firstMark;
    HR := XSTART;
    VT := YSTART;

    while Abs(toly) <= Abs(farBound) do
      begin
        tolyString := TalyToString(toly);
        Writeln(F, HR : 3 : 2, '  ', VT : 3 : 2, '  (', tolyString, ') showyhatch');
        VT := VT + VSTEP;
        toly := toly + taly;
      end;

  end; {PostVertAxis}

 {_________________________________________________}

  procedure PostZeroPiAxis (var F: text;
                  var POSTBOX: IBOX);

    var
      XR, YT, BOXWDT: real;

  begin{ZeroPiAxis}
    BOXWDT := POSTBOX.X2 - POSTBOX.X1;

    XR := POSTBOX.X1;
    YT := POSTBOX.Y1; {type conversion}
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (0) showxhatch');

    XR := POSTBOX.X1 + BOXWDT / 4;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p/4) showxhatch');

    XR := POSTBOX.X1 + BOXWDT / 2;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p/2) showxhatch');

    XR := POSTBOX.X2 - BOXWDT / 4;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (3p/4) showxhatch');

    XR := POSTBOX.X2;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p) showxhatch');
    Writeln(F, 'stroke');
    Writeln(F, 'newpath');

  end;{PostZeroPiAxis}

{_________________________________________________}

  procedure PostDoDecAxis (var F: text;
                  var POSTBOX: IBOX);

    var
      XR, YT, BOXWDT: real;

  begin{ZeroPiAxis}
    BOXWDT := POSTBOX.X2 - POSTBOX.X1;

    XR := POSTBOX.X1;
    YT := POSTBOX.Y1; {type conversion}
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (0) showxhatch');

    XR := POSTBOX.X1 + BOXWDT / 6;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p/6) showxhatch');

    XR := POSTBOX.X1 + BOXWDT / 3;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p/3) showxhatch');

    XR := POSTBOX.X2 - BOXWDT / 2;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p/2) showxhatch');

    XR := POSTBOX.X2 - BOXWDT / 3;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (2p/3) showxhatch');

    XR := POSTBOX.X2 - BOXWDT / 6;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (5p/6) showxhatch');

    XR := POSTBOX.X2;
    Writeln(F, XR : 5 : 2, '  ', YT : 5 : 2, '  (p) showxhatch');
    Writeln(F, 'stroke');
    Writeln(F, 'newpath');

  end;{PostPostDoDecAxis}

 {_________________________________________________}

  procedure PostFrameLite (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX);

    var
      VSTEP, taly: real;

  begin{PostFrameLite}

    with POSTBOX, realBOX do
      begin {with}
        Writeln(F, '/Symbol findfont');
        Writeln(F, '10 scalefont  setfont');
        Writeln(F, X1 : 2, '  ', Y1 : 2, ' moveto ');
        Writeln(F, X1 : 2, '  ', Y2 : 3, '  lineto');
        Writeln(F, X2 : 3, '  ', Y2 : 3, '  lineto');
        Writeln(F, X2 : 2, '  ', Y1 : 3, '  lineto');
        Writeln(F, 'closepath');
        Writeln(F, 'stroke');
        Writeln(F, 'newpath');

        yLB := 0.0;
        yUB := 1.2 * yMax;

        Tallypoints(yUB, taly);
        VSTEP := taly * (BOXHGT / yUB);

        X0 := X1;
        Y0 := Y1;

        PostVertAxis(F, X0, Y1, taly, yLB, yUB, VSTEP);
        Writeln(F, 'stroke');
        Writeln(F, 'newpath');

        xRange := xMax - xMin;
        yRange := yUB - yLB;

      end; {with POSTBOX, realBOX}

  end; {PostFrameLite}

 {_________________________________________________}

  procedure PostPlot (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);
   {This procedure is for plotting a sequence of NOPUNCT data points}

    var
      i: integer;
      HR, VT, xFactor, yFactor: real;

  begin
    with POSTBOX, realBOX do
      begin {with}
        yRange := yUB - yLB;
        yFactor := BOXHGT / yRange;
        xFactor := BOXWDT / xRange;

        for i := 0 to NOPUNCT - 1 do
          begin {i}
            HR := X1 + i * xFactor;
            VT := Y1 + yFactor * (dataVector[i] - yLB);
            if i = 0 then
              Writeln(F, HR : 3 : 2, '  ', VT : 3 : 2, '   moveto')
            else
              Writeln(F, HR : 3 : 2, '  ', VT : 3 : 2, '   lineto');
          end; {i}

        Writeln(F, 'stroke');
        Writeln(F, 'newpath');

      end; {with POSTBOX, dataBOX}

  end; {PostPlot}

{________________________________________________}

  procedure PostPlot2 (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);

{This is for plotting an arbitrary number of data points over}
{the range defined by the width of the bounding box via the}
{index  i := 0 to Tcap - 1: Tcap := realBOX.NOPUNCT - 1}

    var
      i: integer;
      HR, VT, xFactor, yFactor: real;

  begin
    with POSTBOX, realBOX do
      begin {with}
        yFactor := BOXHGT / yRange;
        xFactor := BOXHGT / xRange;

        Writeln(F, 'newpath');
        HR := BOXWDT;
        VT := Y0 + (dataVector[NOPUNCT - 1] - yLB) * yFactor;
        Writeln(F, HR : 3 : 2, ' ', VT : 3 : 2, ' moveto');

        for i := 0 to NOPUNCT - 1 do
          begin {i}
            HR := X1 + i * xFactor;
            VT := Y1 + (dataVector[i] - yLB) * yFactor;
            if (i mod 8 = 7) or (i = NOPUNCT - 1) then
              Writeln(F, HR : 3 : 2, ' ', VT : 3 : 2)
            else
              Write(F, HR : 3 : 2, ' ', VT : 3 : 2, ' ');
          end; {i}
        Writeln(F, NOPUNCT : 3, ' {lineto} repeat');
        Writeln(F, 'stroke');

      end; {with POSTBOX, dataBOX}

  end; {PostPlot2}

{_________________________________________________}

  procedure PostPlotMod (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);

  {This procedure is for plotting a sequence of BOXWDT data points}

    var
      i: integer;
      HR, VT, yFactor: real;

  begin

    with POSTBOX, realBOX do
      begin {with}
        yRange := yUB - yLB;
        yFactor := BOXHGT / yRange;

        for i := 0 to BOXWDT do
          begin {i}
            HR := X0 + i;
            VT := Y1 + (dataVector[i] - yLB) * yFactor;
            if i = 0 then
              Writeln(F, HR : 5 : 2, '  ', VT : 5 : 2, '  moveto')
            else
              Writeln(F, HR : 5 : 2, '  ', VT : 5 : 2, '  lineto');
          end; {i}
        Writeln(F, 'stroke');

      end; {with POSTBOX, dataBOX}

  end; {PostPlotMod}

  {_________________________________________________}

  procedure PostPlotMod2 (var F: text;
                  var realBOX: rBOX;
                  var POSTBOX: IBOX;
                  var dataVector: longVector);

{This is for plotting a series of function evaluations that are equal}
{in number to the width to the bounding box measured in pixelpoints}
{via the index  i := 0 to BOXWDT - 1}

    var
      i, BOXWDT, BOXHGT, YZERO: integer;
      HR, VT, xRange, yRange: real;

  begin
    BOXWDT := POSTBOX.X2 - POSTBOX.X1;
    BOXHGT := POSTBOX.Y2 - POSTBOX.Y1;
    YZERO := POSTBOX.Y0;
    yRange := realBOX.yUB - realBOX.yLB;
{xRange := realBOX.xRB - realBOX.xLB;}

    Writeln(F, 'newpath');
    Writeln(F, '/abscissa ', BOXWDT : 3, ' def');

    HR := BOXWDT;
    VT := YZERO + (dataVector[BOXWDT - 1] * BOXHGT / yRange);
    Writeln(F, HR : 3 : 2, ' ', VT : 3 : 2, ' moveto');
{we are plotting in the reverse direction of x}

    for i := 0 to BOXWDT - 1 do
      begin {i}
        VT := YZERO + (dataVector[i] * BOXHGT / yRange);
{Here we  impose a limiting value on VT to keep the plot within the  bounding box}
        if VT > POSTBOX.Y2 then
          VT := POSTBOX.Y2;

        if (i mod 8 = 7) then
          Writeln(F, VT : 3 : 2) {this is to break the lines}
        else
          Write(F, VT : 3 : 2, ' ');
      end; {i}
    Write(F, BOXWDT : 3); {repeat these many times}
    Writeln(F, ' {/abscissa abscissa 1 sub def abscissa exch lineto} repeat');
    Writeln(F, 'stroke');

  end; {PostPlotMod2}

{_________________________________________________}

  procedure PostSpectraPlot (var F: text;
                  var plotBOX: rBOX;
                  var plotVector: longVector;
                  var POSTBOX: IBOX;
                  var legend: string);
    var
       postFileName: string;

  begin

    Write('    Name the Postscript File = ');
    Readln(postFileName);
    if postFileName <> '' then
      begin {Postfile}
        Assign(F, postFileName);
        ReWrite(F);
        PostHeader(F, POSTBOX, TeXFormat);
        POSTBOX.xScale := false;
        PostFrameLite(F, plotBOX, POSTBOX);
        PostDoDecAxis(F, POSTBOX);

{PostFrame(F, plotBOX, POSTBOX);}
{PostZeroPiAxis(F, POSTBOX);}
{PostPlotMod(F, plotBOX, POSTBOX, plotVector);}

        PostPlotMod2(F, plotBOX, POSTBOX, dataVector);
        PostFooter(F, POSTBOX, legend, TexFormat);
        POSTBOX.xScale := true;
        Close(F);
      end; {Postfile}
  end; {PostSpectra}

 {_________________________________________________}

end. {POST: Unit 5 of SEASQUAD.PAS}

