unit SCREEN; {Unit 4 of SEASCAPE.PAS}

interface

  uses
    GLOBALS, UTILS, MATHS, Dos, Crt, Graph;

  procedure MarksAndNumbers (XSTART, YSTART: integer;
                  taly, firstMark, farBound, STEP: real;
                  Axis: string);

  procedure ScreenFrameLite (var realBOX: rBOX;
                  var SCREENBOX: IBOX);

  procedure VertAxis (XSTART, YSTART: integer;
                  taly, firstMark, farBound, VSTEP: real);

  procedure ZeroPiAxis (var SCREENBOX: IBOX);

  procedure DoDecAxis (var SCREENBOX: IBOX);

  procedure ScreenPlot (var realBOX: rBOX;
                  var SCREENBOX: IBOX;
                  var dataVector: longVector);

  procedure ScreenPlotMod (var realBOX: rBOX;
                  var SCREENBOX: IBOX;
                  var dataVector: longVector);

  procedure Rotate (aPoint: complex;
                  centre: complex;
                  angle: real;
                  var newPoint: complex);

  procedure PolePlot (var SCREENBOX: IBOX;
                  var lambda: complex);

  procedure Circle (xCentre, yCentre, radius: integer);

  procedure ScreenAargand (var SCREENBOX: IBOX;
                  p, q: integer;
                  var poles, zeros: complexVector);

implementation

  {__________________________________________________}

  procedure MarksAndNumbers (XSTART, YSTART: integer;
                  taly, firstMark, farBound, STEP: real;
                  Axis: string);
       {This DOS Routine differs from the Macintosh Version}

    var
      toly, HRL, VRL: real;
      HR1, HR2, VT1, VT2, tolyWidth: integer;
      HINC, VINC, PENLEFT, PENDOWN: integer;
      tolyString: string;

  begin {MarksAndNumbers}

    if Axis = 'yAxis' then
      begin {Pixel Parameters}
        HINC := 5;
        VINC := 0;
        PENDOWN := -(TextHeight('NUMBERS') div 2);
      end;
    if Axis = 'xAxis' then
      begin
        HINC := 0;
        VINC := -5;
        PENDOWN := 20;
      end; {Pixel Parameters}

    toly := firstMark;
    HRL := XSTART;
    HR1 := XSTART;
    HR2 := HR1 + HINC;
    VRL := YSTART;
    VT1 := YSTART;
    VT2 := VT1 + VINC;

    while Abs(toly) <= Abs(farBound) do

      begin {while toly}
        tolyString := TalyToString(toly);
        tolyWidth := TextWidth(tolyString);
        if axis = 'xAxis' then
          PENLEFT := Round(tolyWidth / 2.0);
        if axis = 'yAxis' then
          PENLEFT := tolyWidth + 15;

      {Numbers}
        MoveTo(HR1 - PENLEFT, VT1 + PENDOWN);
        OutText(tolyString);

       {Hatchmarks}
        MoveTo(HR1, VT1);
        LineTo(HR2, VT2);

       {Increments}
        if axis = 'xAxis' then
          HRL := HRL + STEP;
        HR1 := Round(HRL);
        HR2 := HR1 + HINC;
        if axis = 'yAxis' then
          VRL := VRL - STEP;
        VT1 := Round(VRL);
        VT2 := VT1 + VINC;

        toly := toly + taly;
      end; {while toly}

  end; {MarksAndNumbers}

  {_________________________________________________}

  procedure ScreenFrameLite (var realBOX: rBOX;
                  var SCREENBOX: IBOX);

    var
      BOXHGT: integer;
      XSTART: integer;
      VSTEP, taly: real;
      yMax: real;
      lowerBound, upperBound: real;

  begin
    yMax := realBOX.yMax; {the maximum value of y in the Data vector}

    BOXHGT := SCREENBOX.Y2 - SCREENBOX.Y1; {Height of Bounding Box}

    Rectangle(SCREENBOX.X1, SCREENBOX.Y1, SCREENBOX.X2, SCREENBOX.Y2);

    lowerBound := 0.0;
    upperBound := 1.2 * yMax;
    Tallypoints(upperBound, taly);

    XSTART := SCREENBOX.X1;

    VSTEP := taly * (BOXHGT / upperBound);
    VertAxis(XSTART, SCREENBOX.Y2, taly, lowerBound, upperBound, VSTEP);

    realBOX.yUB := upperBound;
    realBOX.yLB := lowerBound;
    realBOX.xLB := realBOX.xMin;
    realBOX.xRB := realBOX.xMax;

    SCREENBOX.X0 := SCREENBOX.X1;
    SCREENBOX.Y0 := SCREENBOX.Y2;

  end; {ScreenFrameLite}

  {_________________________________________________}

  procedure VertAxis (XSTART, YSTART: integer;
                  taly, firstMark, farBound, VSTEP: real);

    var
      toly, VRL: real;
      HR1, HR2, VT, tolyWidth: integer;
      HINC, PENLEFT, PENDOWN: integer;
      tolyString: string;

  begin {VertAxis}
    HINC := 5;
    PENDOWN := 4;

    toly := firstMark;
    HR1 := XSTART;
    HR2 := HR1 + HINC;
    VRL := YSTART;
    VT := YSTART;

    while Abs(toly) <= Abs(farBound) do
      begin {while toly}

        tolyString := TalyToString(toly);
        tolyWidth := TextWidth(tolyString);
        PENLEFT := tolyWidth + 15;

      {Numbers}
        MoveTo(HR1 - PENLEFT, VT + PENDOWN);
        OutText(tolyString);

       {Hatchmarks}
        MoveTo(HR1, VT);
        LineTo(HR2, VT);

       {Increments}
        VRL := VRL - VSTEP;
        VT := Round(VRL);

        toly := toly + taly;
      end; {while toly}

  end; {VertAxis}

   {________________________________________________}

  procedure ZeroPiAxis (var SCREENBOX: IBOX);
       {This DOS Routine differs from the Macintosh Version}

    var
      HR, VT1, VT2: integer;
      BOXWDT, PENDOWN, PENLEFT: integer;

  begin{ZeroPiAxis}
    BOXWDT := SCREENBOX.X2 - SCREENBOX.X1;
    PENLEFT := 12;
    PENDOWN := 20;

    VT1 := SCREENBOX.Y2;
    VT2 := VT1 - 5;
    HR := SCREENBOX.X1;
    MoveTo(HR - 2, VT1 + PENDOWN);
    OutText('0');

    HR := SCREENBOX.X1 + Round(BOXWDT / 4.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - 8, VT1 + PENDOWN);
    OutText('p/4');

    HR := SCREENBOX.X1 + Round(BOXWDT / 2.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - 8, VT1 + PENDOWN);
    OutText('p/2');

    HR := SCREENBOX.X2 - Round(BOXWDT / 4.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - PENLEFT, VT1 + PENDOWN);
    OutText('3p/4');

    HR := SCREENBOX.X2;
    MoveTo(HR - 2, VT1 + PENDOWN);
    OutText('p');

  end;{ZeroPiAxis}

  {_________________________________________________}

  procedure DoDecAxis (var SCREENBOX: IBOX);

    var
      HR, VT1, VT2, BOXWDT, PENDOWN, PENLEFT: integer;

  begin{DoDecAxis}
    BOXWDT := SCREENBOX.X2 - SCREENBOX.X1;
    PENLEFT := 12;
    PENDOWN := 20;


    VT1 := SCREENBOX.Y2;
    VT2 := VT1 - 5;
    HR := SCREENBOX.X1;
    MoveTo(HR - 2, VT1 + PENDOWN);
    OutText('0');

    HR := SCREENBOX.X1 + Round(BOXWDT / 6);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - 8, VT1 + PENDOWN);
    OutText('p/6');

    HR := SCREENBOX.X1 + Round(BOXWDT / 3.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - 8, VT1 + PENDOWN);
    OutText('p/3');

    HR := SCREENBOX.X2 - Round(BOXWDT / 2);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
    MoveTo(HR - 8, VT1 + PENDOWN);
    OutText('p/2');

    HR := SCREENBOX.X2 - Round(BOXWDT / 3.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
     MoveTo(HR - 12, VT1 + PENDOWN);
    OutText('2p/3');

    HR := SCREENBOX.X2 - Round(BOXWDT / 6.0);
    MoveTo(HR, VT1);
    LineTo(HR, VT2);
     MoveTo(HR - 12, VT1 + PENDOWN);
    OutText('5p/6');

    HR := SCREENBOX.X2;
    MoveTo(HR - 2, VT1 + PENDOWN);
    OutText('p');

  end;{DoDecAxis}

{_________________________________________________}

  procedure ScreenPlot (var realBOX: rBOX;
                  var SCREENBOX: IBOX;
                  var dataVector: longVector);

{This is for plotting an arbitrary number of data points over}
{the range defined by the width of the bounding box}

    var
      i, HR, VT, BOXHGT: integer;
      xRange, yRange, BOXWDT: real;
      store: double;

  begin
    BOXWDT := SCREENBOX.X2 - SCREENBOX.X1;
    BOXHGT := SCREENBOX.Y2 - SCREENBOX.Y1;
    yRange := realBOX.yUB - realBOX.yLB;
    xRange := realBOX.xRB - realBOX.xLB;

    for i := 0 to realBOX.NOPUNCT - 1 do
      begin {i}
        store := i * BOXWDT;
        store := store / (realBOX.NOPUNCT - 1);
        HR := SCREENBOX.X1 + Round(store);

        store := (dataVector[i] - realBOX.yLB) / yRange;
        VT := Round(SCREENBOX.Y2 - store * BOXHGT);

        if i = 0 then
          MoveTo(HR, VT)
        else
          LineTo(HR, VT);
      end; {i}

  end; {ScreenPlot}

{_________________________________________________}

  procedure ScreenPlotMod (var realBOX: rBOX;
                  var SCREENBOX: IBOX;
                  var dataVector: longVector);

{This is for plotting a series of function evaluations thar are equal}
{in number to the width to the bounding box measured in pixelpoints.}

    var
      i, HR, VT, XORIGIN, YORIGIN, BOXWDT, BOXHGT: integer;
      store, yRange: real;

  begin
    yRange := realBOX.yUB - realBOX.yLB;
    BOXWDT := SCREENBOX.X2 - SCREENBOX.X1;
    BOXHGT := SCREENBOX.Y2 - SCREENBOX.Y1;
    YORIGIN := Round(SCREENBOX.Y0);
    XORIGIN := Round(SCREENBOX.X0);

    for i := 0 to BOXWDT do
      begin {i}
        HR := XORIGIN + i;
        store := dataVector[i] * (BOXHGT / yRange);
        VT := YORIGIN - Round(store);
        if i = 0 then
          MoveTo(HR, VT)
        else
          LineTo(HR, VT);
      end; {i}
  end; {ScreenPlotMod}

{________________________________________________}

  procedure Rotate (aPoint: complex;
                  centre: complex;
                  angle: real;
                  var newPoint: complex);
    var
      thePolar: polar;
  begin
    newPoint.re := aPoint.re - centre.re;
    newPoint.im := aPoint.im - centre.im;
    ComplexToPolar(newPoint, thePolar);
    thePolar.argu := thePolar.argu + angle;
    PolarToComplex(thePolar, newPoint);
    newPoint.re := newPoint.re + centre.re;
    newPoint.im := newPoint.im + centre.im;
  end; {Rotate}

 {________________________________________________}

  procedure PolePlot (var SCREENBOX: IBOX;
                  var lambda: complex);
    var
      P, A, B, C, D, centre: complex;
      thePole: polar;
      theArgument, theModulus: real;
      RADIUS: integer;
  begin
    ComplexToPolar(lambda, thePole);
    theArgument := thePole.argu;
    theModulus := thePole.modu;

  {writeln(theArgument : 3 : 3);}
    centre.re := SCREENBOX.XC;
    centre.im := SCREENBOX.YC;
    RADIUS := 72;
    P.re := theModulus * RADIUS + centre.re;
    P.im := centre.im;
    A.re := P.re + 5;
    A.im := P.im + 5;
    B.re := P.re + 5;
    B.im := P.im - 5;
    C.re := P.re - 5;
    C.im := P.im - 5;
    D.re := P.re - 5;
    D.im := P.im + 5;

    Rotate(P, centre, theargument, P);
    Rotate(A, centre, theargument, A);
    Rotate(B, centre, theargument, B);
    Rotate(C, centre, theargument, C);
    Rotate(D, centre, theargument, D);
    MoveTo(Round(centre.re), Round(centre.im));
    LineTo(Round(P.re), Round(P.im));
    MoveTo(Round(A.re), Round(A.im));
    LineTo(Round(C.re), Round(C.im));
    MoveTo(Round(B.re), Round(B.im));
    LineTo(Round(D.re), Round(D.im));

  end; {PolePlot}

{________________________________________________}

  procedure Circle (xCentre, yCentre, radius: integer);
    var
      LEFT, TOP, BOT, RIGHT: integer;

  begin
    LEFT := xCentre - RADIUS;
    TOP := yCentre - RADIUS;
    BOT := yCentre + RADIUS;
    RIGHT := xCentre + RADIUS;
    {FrameOval(TOP, LEFT, BOT, RIGHT); }
  end; {Circle}

 {________________________________________________}

  procedure ScreenAargand (var SCREENBOX: IBOX;
                  p, q: integer;
                  var poles, zeros: complexVector);

    var
      i, CTX, CTY, XSTART, XEND, YSTART, YEND, RADIUS: integer;

  begin {ScreenAargand }

    CTX := SCREENBOX.XC;
    CTY := SCREENBOX.YC;
    RADIUS := 72;
    Circle(CTX, CTY, RADIUS);

     {Horizontal Axis}
    XSTART := CTX - Round(1.25 * RADIUS);
    XEND := CTX + Round(1.25 * RADIUS);
    YSTART := CTY;
    YEND := CTY;
    MoveTo(XSTART, YSTART);
    LineTo(XEND, YEND);

     {Vertical Axis}
    XSTART := CTX;
    XEND := CTX;
    YSTART := CTY + Round(1.25 * RADIUS);
    YEND := CTY - Round(1.25 * RADIUS);
    MoveTo(XSTART, YSTART);
    LineTo(XEND, YEND);

    for i := 1 to p do {Plot the poles}
      PolePlot(SCREENBOX, poles[i]);

     {NB. plotting poles requires an elaborate procedure, PlotPole, to ensure that}
     {the crosses which mark the poles maintain their alignment with the radii}

    for i := 1 to q do
      begin {Plot the zeros}
        XEND := CTX + Round(zeros[i].re * RADIUS);
        YEND := CTY - Round(zeros[i].im * RADIUS);
        MoveTo(CTX, CTY);
        LineTo(XEND, YEND);
        Circle(XEND, YEND, 4);
      end;

  end; {ScreenAargand}

  {_________________________________________________}



end. {SCREEN: Unit 4 of SEASCAPE.PAS}

